/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ambari.server.view;

import org.junit.Test;

import junit.framework.Assert;

/**
 * DefaultMasker test.
 */
public class DefaultMaskerTest {
  private DefaultMasker masker = new DefaultMasker();

  @Test
  public void testMask() throws Exception {
    final String source = "unmasked";
    final String masked = masker.mask(source);
    Assert.assertNotNull(masked);
    Assert.assertTrue(masked.length() > 0);
  }

  @Test
  public void testMaskUnmask() throws Exception {
    final String source = "unmasked";
    final String masked = masker.mask(source);
    final String unmasked = masker.unmask(masked);
    Assert.assertEquals(source, unmasked);
  }
}
